<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) ) {
exit;
}

class Skolka_Headlines_Widget extends Widget_Base {
	public function get_name() {
	  return 'skolka-headlines';
	}
	public function get_title() {
	  return 'Headlines';
	}
	public function get_icon() {
	  return 'eicon-t-letter';
	}
	public function get_categories() {
	  return [ 'themezinho' ];
	}

  // Registering Controls
	protected function register_controls() {
	  $this->start_controls_section( 'skolka_headlines', [
		'label' => esc_html__( 'Headlines', 'themezinho' ),
	  ] );


	  $this->add_control(
		'title',
		array(
		'label' => __( 'Title', 'themezinho' ),
		'type' => Controls_Manager::TEXT,
		'default' => __( 'Title', 'themezinho' ),
	  )
	  );



	  $this->add_control(
		'hr0',
		[
			'type' => \Elementor\Controls_Manager::DIVIDER,
		]
	  );

	  $this->add_control(
		'html_tag',
		array(
		'label' => __( 'HTML Tag', 'themezinho' ),
		'type' => Controls_Manager::SELECT,
		'options' => [
		  'h1' => esc_html__( 'H1', 'themezinho' ),
		  'h2' => esc_html__( 'H2', 'themezinho' ),
		  'h3' => esc_html__( 'H3', 'themezinho' ),
		  'h4' => esc_html__( 'H4', 'themezinho' ),
		  'h5' => esc_html__( 'H5', 'themezinho' ),
		  'h6' => esc_html__( 'H6', 'themezinho' ),
		  'small' => esc_html__( 'Small', 'themezinho' ),
		],
		'default' => 'h2'
	  )
	  );



	  $this->add_control(
		'color',
		array(
		'label' => __( 'Color', 'themezinho' ),
		'type' => Controls_Manager::COLOR,
		'selectors' => [
				'{{WRAPPER}} .headlines' => 'color: {{VALUE}};'
			],
	  )
	  );

	  $this->add_control(
		'font_weight',
		[
			'label' => __( 'Font Weight', 'themezinho' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
		'400' => esc_html__( '400', 'themezinho' ),
		'600' => esc_html__( '600', 'themezinho' ),
		'800' => esc_html__( '800', 'themezinho' ),

			],
			'default' => '600',
			'selectors' => [
				'{{WRAPPER}} .headlines > *' => 'font-weight: {{VALUE}};'
			],
		]
	  );


		$this->add_control(
		'line_height',
		array(
		'label' => __( 'Line Height', 'themezinho' ),
		'type' => Controls_Manager::TEXT,
		'default' => __( 'Normal', 'themezinho' ),
		'selectors' => [
			'{{WRAPPER}} .headlines > *' => 'line-height: {{VALUE}};'
		],
	  )
	  );

	  $this->add_responsive_control(
			'font_size',
			[
				'label' => esc_html__( 'Font Size', 'themezinho' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 8,
						'max' => 60,
						'step' => 1,
					],
				],
		  'default' => [
					'unit' => 'px',
					'size' => 20,
				],
				'selectors' => [
					'{{WRAPPER}} .headlines > *' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);


	  $this->add_responsive_control(
		'alignment',
		[
			'label' => __( 'Alignment', 'themezinho' ),
			'type' => \Elementor\Controls_Manager::CHOOSE,
			'options' => [
				'left'    => [
					'title' => __( 'Left', 'themezinho' ),
					'icon' => 'eicon-text-align-left',
				],
				'center' => [
					'title' => __( 'Center', 'themezinho' ),
					'icon' => 'eicon-text-align-center',
				],
				'right' => [
					'title' => __( 'Right', 'themezinho' ),
					'icon' => 'eicon-text-align-right',
				],
			],
			'default' => 'left',
			'selectors' => [
				'{{WRAPPER}} .headlines' => 'text-align: {{VALUE}};'
			],
		]
	  );

	  $this->end_controls_section();
	  /*****   END CONTROLS SECTION   ******/


	}
	protected function render() {
	  $settings = $this->get_settings_for_display();

		?>

	<div class="headlines">
	  <<?php echo esc_attr($settings['html_tag']); ?>><?php echo esc_html($settings['title']); ?>
	  </<?php echo esc_attr($settings['html_tag']); ?>>
	</div>

<?php


	}
}
