<?php
/*
Plugin Name: Skolka Core
Plugin URI: https://themezinho.net/
Description: Themezinho Premium Themes
Author: Themezinho
Version: 1.0.0
Author URI: https://themezinho.net/
Requires at least: 5.0
Tested up to: 5.8
Requires PHP: 5.6
*/

define( 'THEMEZINHO_CORE_PATH', plugin_dir_path( __FILE__ ) );
define( 'THEMEZINHO_CORE_URI', plugins_url( 'skolka_core/' ) );


// ADD ELEMENTOR
require_once  'inc/elementor/themezinho-elementor.php' ;
function add_elementor_widget_categories( $elements_manager ) {
  $categories                 = [];
  $categories[ 'themezinho' ] = [
	'title' => 'Themezinho',
	'icon' => 'eicon-elementor-circle'
  ];

  $old_categories = $elements_manager->get_categories();
  $categories     = array_merge( $categories, $old_categories );

  $set_categories = function ( $categories ) {
		$this->categories = $categories;
	};

  $set_categories->call( $elements_manager, $categories );
}
add_action( 'elementor/elements/categories_registered', 'add_elementor_widget_categories' );


// ADD PRODUCT VARIATION IMAGES
add_filter( 'variation_images/settings/path', 'themezinho_variation_images_settings_path' );
function themezinho_variation_images_settings_path( $path ) {
  $path = THEMEZINHO_CORE_PATH . 'inc/variation-images/';
  return $path;
}

add_filter( 'variation_images/settings/dir', 'themezinho_variation_images_settings_dir' );
function themezinho_variation_images_settings_dir( $dir ) {
  $dir = THEMEZINHO_CORE_URI . 'inc/variation-images/';
  return $dir;
}

require THEMEZINHO_CORE_PATH . 'inc/variation-images/woocommerce-additional-variation-images.php';




// ADD PRODUCT SWATCHES
add_filter( 'swatches/settings/path', 'themezinho_swatches_settings_path' );
function themezinho_swatches_settings_path( $path ) {
  $path = THEMEZINHO_CORE_PATH . 'inc/swatches/';
  return $path;
}

add_filter( 'swatches/settings/dir', 'themezinho_swatches_settings_dir' );
function themezinho_swatches_settings_dir( $dir ) {
  $dir = THEMEZINHO_CORE_URI . 'inc/swatches/';
  return $dir;
}

require THEMEZINHO_CORE_PATH . 'inc/swatches/woocommerce-swatches.php';





// ADD ACF
add_filter( 'acf/settings/path', 'themezinho_acf_settings_path' );
function themezinho_acf_settings_path( $path ) {
  $path = THEMEZINHO_CORE_PATH . '/inc/acf/';
  return $path;
}

add_filter( 'acf/settings/dir', 'themezinho_acf_settings_dir' );
function themezinho_acf_settings_dir( $dir ) {
  $dir = THEMEZINHO_CORE_URI . '/inc/acf/';
  return $dir;
}

add_filter( 'acf/settings/show_admin', '__return_false' );
require THEMEZINHO_CORE_PATH . '/inc/acf/acf.php';



// ADD CUSTOM TAXONOMY AND THEME OPTIONS
require_once THEMEZINHO_CORE_PATH . '/inc/theme-options.php';
require_once THEMEZINHO_CORE_PATH . '/inc/cpt-taxonomy.php';




// DASHBOARD CHART
function my_purchases_chart_widget_callback() {
    // Get the current user
    $current_user = wp_get_current_user();

    // Get the purchase data for the user
    $args = array(
        'customer_id' => $current_user->ID,
        'status' => array('wc-completed', 'wc-processing', 'wc-on-hold')
    );
    $orders = wc_get_orders($args);
    $purchaseData = array();
    $productCountData = array();
    foreach ($orders as $order) {
        $month = date('M', strtotime($order->get_date_created()));
        $amount = $order->get_total();
        $productCount = 0;
        foreach ($order->get_items() as $item_id => $item) {
            $productCount += $item->get_quantity();
        }
        if (isset($purchaseData[$month])) {
            $purchaseData[$month] += $amount;
            $productCountData[$month] += $productCount;
        } else {
            $purchaseData[$month] = $amount;
            $productCountData[$month] = $productCount;
        }
    }
    ksort($purchaseData);
    ksort($productCountData);
    $purchaseData = array_values($purchaseData);
    $productCountData = array_values($productCountData);

    $lastSixMonthsData = array_slice( $purchaseData, -6 );
    $lastSixMonthsProductCountData = array_slice( $productCountData, -6 );

    // Get the labels and amounts for each dataset
    $lastSixMonthsLabels = array(date('M', strtotime('-6 months')), date('M', strtotime('-5 months')), date('M', strtotime('-4 months')), date('M', strtotime('-3 months')), date('M', strtotime('-2 months')), date('M', strtotime('-1 month')));
    $lastSixMonthsAmounts = $lastSixMonthsData;
    $lastSixMonthsProductCounts = $lastSixMonthsProductCountData;

    // Output the chart using JavaScript
    echo '<canvas id="myChart" width="500" height="200"></canvas>';
    echo '<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>';
    echo '<script>
        var ctx = document.getElementById(\'myChart\').getContext(\'2d\');
        var myChart = new Chart(ctx, {
            type: \'bar\',
            data: {
                labels: ' . json_encode( $lastSixMonthsLabels ) . ',
                datasets: [
                    {
                        label: \'Last 6 Months - Amount\',
                        data: ' . json_encode( $lastSixMonthsAmounts ) . ',
                        backgroundColor: \'rgba(255, 206, 86, 0.2)\',
                        borderColor: \'rgba(255, 206, 86, 1)\',
                        borderWidth: 1
                    },
                    {
                        label: \'Last 6 Months - Product Count\',
                        data: ' . json_encode( $lastSixMonthsProductCounts ) . ',
                        backgroundColor: \'rgba(54, 162, 235, 0.2)\',
                        borderColor: \'rgba(54, 162, 235, 1)\',
                        borderWidth: 1
                    }
                ]
            },
            options: {
                scales: {
                    yAxes: [{
                        ticks: {
                            beginAtZero: true
                        }
                    }]
                }
            }
        });
    </script>';
}

add_action('woocommerce_account_dashboard', 'my_purchases_chart_widget_callback');




// WIDGET SIDEBAR CATEGORIES
class Skolka_Sidebar_Categories_Widget extends WP_Widget {

	public function __construct() {
	  parent::__construct(
		'skolka_sidebar_categories_widget',
		__('Skolka Sidebar Categories', 'skolka'),
		array( 'description' => __( 'Displays subcategories of the current category', 'skolka' ), )
	  );
	}

	public function widget( $args, $instance ) {
		if ( ! is_tax( 'product_cat' ) ) {
			  return;
		}
$current_category = get_queried_object();
$subcategories    = get_terms( array(
	'taxonomy' => 'product_cat',
	'parent' => $current_category->term_id,
) );


		?>
<div class="skolka-sidebar-categories">
<ul class="current-categories">

  <li class="current-cat"><span><?php echo esc_html( $current_category->name ); ?></span></li>
	<?php foreach ( $subcategories as $subcategory ) : ?>
		<li><a href="<?php echo esc_url( get_term_link( $subcategory ) ); ?>"><?php echo esc_html( $subcategory->name ); ?></a></li>
	<?php endforeach; ?>
	  </ul>
	<hr />
	<ul class="other-categories">
	<?php
		if (0 != $current_category->parent) {
			$args     = array(
			  'taxonomy'     => $current_category->taxonomy,
			  'parent'       => $current_category->parent,
			  'exclude'      => $current_category->term_id,
			);
			$siblings = get_terms( $args );
			if ( $siblings ) :
				?>
			  <?php foreach ( $siblings as $sibling ) : ?>
					<li><a href="<?php echo esc_url( get_term_link( $sibling ) ); ?>"><?php echo esc_html( $sibling->name ); ?></a></li>
	  <?php endforeach; ?>
		<?php
		endif;
		} else {
		  $args     = array(
			'taxonomy'     => $current_category->taxonomy,
			'parent'       => 0,
			'exclude'      => $current_category->term_id,
		  );
		  $siblings = get_terms( $args );
			if ( $siblings ) :
				?>
		  <?php foreach ( $siblings as $sibling ) : ?>
				<li><a href="<?php echo esc_url( get_term_link( $sibling ) ); ?>"><?php echo esc_html( $sibling->name ); ?></a></li>
	  <?php endforeach; ?>
	  <?php
		endif;
		}
		?>
  </ul>
</div>

	<?php
	}
}
function register_skolka_sidebar_categories_widget() {
  register_widget( 'Skolka_Sidebar_Categories_Widget' );
}
add_action( 'widgets_init', 'register_skolka_sidebar_categories_widget' );







// AFTER IMPORT THEME OPTIONS
function skolka_after_import() {

  $icon_box = array(
    array(
      'footer_bar_icon' => 843,
      'footer_bar_text' => 'Fast Next Day Delivery',
    ),
    array(
      'footer_bar_icon' => 844,
      'footer_bar_text' => '30 Days Return & Refund',
    ),
    array(
      'footer_bar_icon' => 845,
      'footer_bar_text' => 'All Around Europe',
    ),
    array(
    'footer_bar_icon' => 846,
      'footer_bar_text' => 'Secure Shopping',
    ),
  );

  update_field( 'icon_box', $icon_box, 'option' );
  update_field( 'display_topbar', 1, 'option' );
  update_field( 'display_search', 1, 'option' );
  update_field( 'display_wishlist', 1, 'option' );
  update_field( 'display_account', 1, 'option' );
  update_field( 'display_bag', 1, 'option' );
  update_field( 'enable_footer_icon_bar', 1, 'option' );
  update_field( 'archive_show_sidebar', 'yes', 'option' );
  update_field( 'enable_search_form', 1, 'option' );




  update_field( 'field_639cf79bf4d79', 1141, 'option' );
  update_field( 'field_639cf79bf4d73', 1142, 'option' );
  update_field( 'field_5c76219fed131', 1143, 'option' );


  update_field( 'field_5e3e82f74502d', 854, 855, 856, 'option' );

  update_field( 'topbar_text', wp_kses_post( '<span>Need support ? </span> Call +0 123-456-7890 for Instant Assistance' ), 'option' );
  update_field( 'footer_copyright_text', wp_kses_post( 'Skolka | A Contemporary E-Commerce Theme' ), 'option' );

}
